@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,11 +17,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import pkg_resources
+
 from .drawer import draw_context, draw
 from .parser import parse, empty_page
 
-__version__ = '0.9.0'
+__version__ = pkg_resources.get_distribution('remt').version
 
-__all__ = ['draw_context', 'draw', 'parse', 'empty_page', '__version__']
+__all__ = ['draw_context', 'draw', 'parse', 'empty_page']
 
 # vim: sw=4:et:ai
