@@ -22,9 +22,10 @@ Command line commands.
 """
 
 import argparse
-import asyncssh  # type: ignore
+import asyncssh
 import configparser
 import json
+import logging
 import os.path
 import shutil
 import typing as tp
@@ -38,7 +39,7 @@ from functools import partial
 from uuid import uuid4 as uuid
 
 import remt
-from .data import Items
+from .data import Items, _ERRORS
 from .error import ConfigError, FileError, ConnectionError
 from .indexer import ann_text, fmt_ann_text
 from .meta import Meta, MetaDir, BASE_DIR, fn_path, cache_dir, read_meta, \
@@ -47,6 +48,8 @@ from .parser import parse_highlights
 from .pdf import pdf_open
 from .util import flatten
 
+logger = logging.getLogger(__name__)
+
 FILE_TYPE = {
     'CollectionType': 'd',
 }
@@ -131,6 +134,8 @@ async def remt_ctx(
             raise
     finally:
         shutil.rmtree(dir_data)
+        for msg in _ERRORS:
+            logger.warning(msg)
 
 def norm_path(path: str) -> str:
     """
@@ -208,9 +213,9 @@ def parse_page(fin: str, fin_highlights: str, page_number: int) -> Items:
             highlights = []
 
         with open(fin, 'rb') as fb:
-            yield from remt.parse(fb, page_number, highlights)  # type: ignore
+            yield from remt.parse(fb, page_number, highlights)
     else:
-        yield from remt.empty_page(page_number)  # type: ignore
+        yield from remt.empty_page(page_number)
 
 def get_page_filename(
         base_dir: str,
@@ -289,8 +294,6 @@ async def cmd_ls(args: argparse.Namespace) -> None:
         start = None
         if path:
             start = fn_metadata(meta, path)['uuid']
-
-        if path:
             meta = ls_filter_path(meta, path)
 
         if not args.recursive:
