@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #
 
 """
-Constants for `remt` project.
+Constants for Remt project.
 """
 
 # reMarkable tablet device text width and height
