@@ -37,7 +37,9 @@ PEN_WIDTH_HIGHLIGHTER = 30
 
 TEXT_SELECTION_ORDER = operator.attrgetter('y', 'x1', 'x2')
 
-BrushPatterns = tp.Dict[str, cairo.SurfacePattern]
+BrushPatterns: tp.TypeAlias = dict[str, cairo.SurfacePattern]
+
+_ERRORS: set[str] = set()
 
 @enum.unique
 class Pen(enum.IntEnum):
@@ -74,7 +76,7 @@ class ColorIndex(enum.IntEnum):
     Color index value.
     """
     BLACK = 0
-    GREY = 1
+    GRAY = 1
     WHITE = 2
 
     YELLOW = 3
@@ -84,8 +86,11 @@ class ColorIndex(enum.IntEnum):
     BLUE = 6
     RED = 7
 
+    GRAY_OVERLAP = 8
+
     @classmethod
-    def _missing_(cls, object: tp.Any) -> ColorIndex:
+    def _missing_(cls, value: tp.Any) -> ColorIndex:
+        _ERRORS.add('Unknown color index: {}'.format(value))
         return ColorIndex.BLACK
 
 class Color(tp.NamedTuple):
