@@ -44,13 +44,14 @@ ALPHA = 0.1
 
 COLOR_STROKE = {
     rdata.ColorIndex.BLACK: rdata.Color(0, 0, 0, 1),
-    rdata.ColorIndex.GREY: rdata.Color(0.5, 0.5, 0.5, 1),
+    rdata.ColorIndex.GRAY: rdata.Color(0.5, 0.5, 0.5, 1),
     rdata.ColorIndex.WHITE: rdata.Color(1, 1, 1, 1),
     rdata.ColorIndex.BLUE: rdata.Color(0, 0.38, 0.79, 1),
     rdata.ColorIndex.RED: rdata.Color(0.85, 0.02, 0.2, 1),
     rdata.ColorIndex.YELLOW: rdata.Color(1, 0.81, 0.0, ALPHA),
     rdata.ColorIndex.GREEN: rdata.Color(0.66, 0.98, 0.36, ALPHA),
     rdata.ColorIndex.PINK: rdata.Color(1, 0.33, 0.81, ALPHA),
+    rdata.ColorIndex.GRAY_OVERLAP: rdata.Color(0.5, 0.5, 0.5, ALPHA),
 }
 
 STYLE_DEFAULT = rdata.Style(
@@ -77,14 +78,16 @@ STYLE_ERASER = rdata.Style(
 
 STYLE_UNKNOWN_TOOL = style_default(tool_line=tool.line_unknown, dash=[1, 5])
 
+DEFAULT_COLOR = COLOR_STROKE[rdata.ColorIndex.BLACK]
+
 path_brush = partial(os.path.join, 'brush')
 
 @singledispatch
-def draw(item: tp.Any, context: rdata.Context):
+def draw(item: tp.Any, context: rdata.Context) -> None:
     raise NotImplementedError('Unknown item to draw: {}'.format(item))
 
 @draw.register
-def _page(page: rdata.Page, context: rdata.Context):
+def _page(page: rdata.Page, context: rdata.Context) -> None:
     surface = context.cr_surface
     page_number = next(context.page_number)
     if page_number:
@@ -106,12 +109,12 @@ def _page(page: rdata.Page, context: rdata.Context):
         cr.scale(factor, factor)
 
 @draw.register
-def _page_end(page: rdata.PageEnd, context: rdata.Context):
+def _page_end(page: rdata.PageEnd, context: rdata.Context) -> None:
     if context.pdf_doc:
         context.cr_ctx.restore()
 
 @draw.register
-def _layer(layer: rdata.Layer, context: rdata.Context):
+def _layer(layer: rdata.Layer, context: rdata.Context) -> None:
     pass
 
 @draw.register
@@ -121,11 +124,12 @@ def _stroke(stroke: rdata.Stroke, context: rdata.Context) -> None:
         logger.debug('Not supported pen for stroke: {}'.format(stroke))
 
     if stroke.color not in COLOR_STROKE:
-        logger.debug('Unknown color index: {}'.format(stroke.color))
+        rdata._ERRORS.add('No color defined for index: {}'.format(stroke.color))
+
     if stroke.pen in (rdata.Pen.ERASER_AREA, rdata.Pen.ERASER):
         color = style.color
     else:
-        color = COLOR_STROKE.get(stroke.color, rdata.ColorIndex.BLACK)
+        color = COLOR_STROKE.get(stroke.color, DEFAULT_COLOR)
 
     cr = context.cr_ctx
     cr.save()
@@ -171,7 +175,7 @@ def draw_line(
         cr.line_to(x, y)
     draw_stroke()
 
-def draw_fill(cr):
+def draw_fill(cr: cairo.Context) -> None:
     """
     Draw Cairo shape and fill.
     """
@@ -179,8 +183,9 @@ def draw_fill(cr):
     cr.fill()
 
 @contextmanager
-def draw_context(pdf_doc: tp.Optional[Poppler.Document], fn_out: str) \
-        -> tp.Generator[rdata.Context, None, None]:
+def draw_context(
+        pdf_doc: tp.Optional[Poppler.Document], fn_out: str
+) -> tp.Generator[rdata.Context, None, None]:
     """
     Create Remt project drawing context.
     """
@@ -241,17 +246,17 @@ def draw_context(pdf_doc: tp.Optional[Poppler.Document], fn_out: str) \
     finally:
         surface.finish()
 
-def load_brush_dir(fn: str) -> rdata.BrushPatterns:
-    replace_null = lambda prev, v: v if v[1] else (v[0], prev[1])
-
-    brushes = ((i, load_brush(fn, i)) for i in range(100))
-    items = accumulate(brushes, replace_null, initial=(None, None))
-    items = itz.drop(1, items)
-    result = tp.cast(rdata.BrushPatterns, dict(items))
-    assert list(result) == list(range(100))
-    if any(v is None for v in result.values()):
-        raise ValueError('Invalid data for brush: {}'.format(fn))
-    return result
+# def load_brush_dir(fn: str) -> rdata.BrushPatterns:
+#     replace_null = lambda prev, v: v if v[1] else (v[0], prev[1])
+#
+#     brushes = ((i, load_brush(fn, i)) for i in range(100))
+#     items = accumulate(brushes, replace_null, initial=(None, None))
+#     items = itz.drop(1, items)
+#     result = tp.cast(rdata.BrushPatterns, dict(items))
+#     assert list(result) == list(range(100))
+#     if any(v is None for v in result.values()):
+#         raise ValueError('Invalid data for brush: {}'.format(fn))
+#     return result
 
 def load_brush(fn: str, n: int) -> tp.Optional[cairo.SurfacePattern]:
     try:
