@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 class RemtError(Exception):
     """
-    Basic class for `remt` project exceptions.
+    Basic class for Remt project exceptions.
     """
 
 class ConnectionError(RemtError):
@@ -29,7 +29,7 @@ class ConnectionError(RemtError):
 
 class ConfigError(RemtError):
     """
-    `remt` project configuration exception.
+    Remt project configuration exception.
     """
 
 class FileError(RemtError):
