@@ -76,8 +76,9 @@ def page_selections(strokes: tp.Tuple[Stroke]) -> tp.List[TextSelection]:
     selections = sorted(selections)
     return merge_line_selection(selections)
 
-def page_text(page: Poppler.Page, selections: tp.List[TextSelection]) \
-        -> tp.List[str]:
+def page_text(
+        page: Poppler.Page, selections: tp.List[TextSelection]
+) -> tp.List[str]:
     """
     Get text for each page stroke.
 
