@@ -184,7 +184,11 @@ def parse_highlight_item(highlight: dict[str, tp.Any]) -> rdata.Stroke:
         (to_seg(x, y + h, h), to_seg(x + w, y + h, h))  # type: ignore
         for x, y, w, h in items
     )
-    color = highlight.get('color', rdata.ColorIndex.YELLOW)
+    default_color = rdata.ColorIndex.YELLOW
+    color = highlight.get('color', default_color)
+    # sometimes remarkable might save highlighter color as black, revert to
+    # default then
+    color = default_color if color == rdata.ColorIndex.BLACK else color
     return rdata.Stroke(
         0,
         rdata.Pen.HIGHLIGHTER_2,
