@@ -24,7 +24,7 @@ information.
 
 from ..data import Pen, TextSelection
 
-def test_pen_higlighter():
+def test_pen_higlighter() -> None:
     """
     Test checking if a pen is a highlighter.
     """
@@ -32,7 +32,7 @@ def test_pen_higlighter():
     assert Pen.is_highlighter(Pen.HIGHLIGHTER_2)
     assert not Pen.is_highlighter(Pen.FINELINER_1)
 
-def test_text_selection_order():
+def test_text_selection_order() -> None:
     """
     Test sorting of text selection.
     """
@@ -53,7 +53,7 @@ def test_text_selection_order():
 
     assert expected == list(result)
 
-def test_text_selection_overlap():
+def test_text_selection_overlap() -> None:
     """
     Test overlapping check of text selections.
     """
@@ -66,7 +66,7 @@ def test_text_selection_overlap():
     assert ts2.overlaps(ts3, 10)
     assert not ts1.overlaps(ts3, 1)
 
-def test_text_selection_merge():
+def test_text_selection_merge() -> None:
     """
     Test merging f text selections.
     """
