@@ -22,6 +22,7 @@ Tests for reading and parsing reMarkable tablet metadata.
 """
 
 import os.path
+import typing as tp
 
 from remt import meta as rmeta
 from remt.error import FileError, ConnectionError
@@ -29,15 +30,15 @@ from remt.error import FileError, ConnectionError
 import pytest
 from unittest import mock
 
-def test_fn_path():
+def test_fn_path() -> None:
     """
     Test creating UUID based path from metadata.
     """
-    meta = {'uuid': 'xyz'}
+    meta = tp.cast(rmeta.Meta, {'uuid': 'xyz'})
     result = rmeta.fn_path(meta, base='/x/y', ext='.met')
     assert '/x/y/xyz.met' == result
 
-def test_read_meta():
+def test_read_meta() -> None:
     """
     Test reading reMarkable tablet metadata.
     """
@@ -50,8 +51,14 @@ def test_read_meta():
         mock_glob.side_effect = [
             # let's make read_meta resistant to some filesystem
             # inconsistencies by introducing non-matching files
-            ['f1.content', 'f2.content', 'f3.content', 'f5.content'],
-            ['f1.metadata', 'f2.metadata', 'f3.metadata', 'f4.metadata'],
+            [
+                'f1.content', 'f2.content', 'f3.content', 'f4.content',
+                'f5.content', 'f6.content', 'f7.content',
+            ],
+            [
+                'f1.metadata', 'f2.metadata', 'f3.metadata', 'f4.metadata',
+                'f5.metadata', 'f6.metadata', 'f7.metadata',
+            ],
         ]
         mock_json_load.side_effect = [
             {'visibleName': 'f1', 'deleted': False},
@@ -63,25 +70,38 @@ def test_read_meta():
 
             {'visibleName': 'f3'},
             {'pages': 5},
-            {'visibleName': 'f4'},
+
+            {'visibleName': 'f4', 'parent': 'f3'},
             {'pages': 6},
+
+            # in trash, shall not be visible in the results
+            {'visibleName': 'f5', 'deleted': False, 'parent': 'trash'},
+            {'pages': 9},
+
+            # there is no parent 'has-parent', so it should be ignored
+            {'visibleName': 'f6', 'deleted': False, 'parent': 'has-parent'},
+            {'pages': 1},
+
+            {'visibleName': 'f7'},
+            {'pages': 12},
         ]
         result = rmeta.read_meta(dirmeta)
-        assert ['f1', 'f2', 'f3'] == list(result)
-        assert {'pages': 3} == result['f1']['content']
-        assert {'pages': 4} == result['f2']['content']
-        assert {'pages': 5} == result['f3']['content']
+        assert ['f1', 'f3', 'f3/f4', 'f7'] == list(result)
+        assert {'pages': 3} == result['f1']['content']  # type: ignore
+        assert {'pages': 5} == result['f3']['content']  # type: ignore
+        assert {'pages': 6} == result['f3/f4']['content']  # type: ignore
+        assert {'pages': 12} == result['f7']['content']  # type: ignore
 
-def test_fn_metadata_error():
+def test_fn_metadata_error() -> None:
     """
     Test if error is raised if there is no metadata for a path.
     """
-    meta = {'a/b/': 1}
+    meta = {'a/b/': tp.cast(rmeta.Meta, {'uuid': 'xyz'})}
 
     with pytest.raises(FileError):
         rmeta.fn_metadata(meta, 'x/y')
 
-def test_is_meta():
+def test_is_meta() -> None:
     """
     Test if a filename is reMarkable tablet meta file.
     """
@@ -89,51 +109,51 @@ def test_is_meta():
     assert rmeta.is_meta('x.metadata')
     assert not rmeta.is_meta('x.pdf')
 
-def test_find_meta_update():
+def test_find_meta_update() -> None:
     """
     Test finding reMarkable tablet meta files, which need to be updated in
     local cache.
     """
     files_remote = {
-        'a': 10,
-        'b': 10,
-        'c': 10,
-        'x': 11,  # updated meta file
-        'y': 11,
-        'n': 10,  # new meta file
+        'a': 10.0,
+        'b': 10.0,
+        'c': 10.0,
+        'x': 11.0,  # updated meta file
+        'y': 11.0,
+        'n': 10.0,  # new meta file
     }
     files_local = {
-        'a': 10,
-        'b': 10,
-        'c': 10,
-        'x': 9,
-        'y': 12,
-        'm': 9,
+        'a': 10.0,
+        'b': 10.0,
+        'c': 10.0,
+        'x': 9.0,
+        'y': 12.0,
+        'm': 9.0,
     }
 
     result = rmeta.find_meta_update(files_remote, files_local)
     expected = ['n', 'x']
     assert expected == list(sorted(result))
 
-def test_find_meta_delete():
+def test_find_meta_delete() -> None:
     """
     Test finding reMarkable tablet meta files, which need to be removed
     from local cache.
     """
     files_remote = {
-        'c': 10,
+        'c': 10.0,
     }
     files_local = {
-        'a': 10,  # to be removed
-        'b': 10,  # to be removed
-        'c': 10,
+        'a': 10.0,  # to be removed
+        'b': 10.0,  # to be removed
+        'c': 10.0,
     }
 
     result = rmeta.find_meta_delete(files_remote, files_local)
     expected = ['a', 'b']
     assert expected == list(sorted(result))
 
-def test_cache_dir():
+def test_cache_dir() -> None:
     """
     Test generating cache directory for reMarkable tablet metadata.
     """
@@ -145,7 +165,7 @@ def test_cache_dir():
         result = rmeta.cache_dir('a-host')
         assert '/home/t-user/.cache/remt/a:b:c' == result
 
-def test_cache_dir_no_mac():
+def test_cache_dir_no_mac() -> None:
     """
     Test if error is raised when no MAC address is returned when generating
     cache directory for reMarkable tablet metadata.
@@ -155,14 +175,14 @@ def test_cache_dir_no_mac():
         with pytest.raises(ConnectionError):
             rmeta.cache_dir('a-host')
 
-def test_ls_local():
+def test_ls_local() -> None:
     """
     Test listing files in local cache.
     """
     with mock.patch('glob.glob') as mock_glob, \
             mock.patch('os.stat') as mock_stat:
 
-        def create_stat(ts):
+        def create_stat(ts: float) -> mock.MagicMock:
             s = mock.MagicMock()
             s.st_mtime = ts
             return s
@@ -186,11 +206,11 @@ def test_ls_local():
         assert expected == result
 
 @pytest.mark.asyncio
-async def test_ls_remote():
+async def test_ls_remote() -> None:
     """
     Test listing metadata files from reMarkable tablet directory.
     """
-    def create_fn(ts):
+    def create_fn(ts: float) -> mock.MagicMock:
         fn = mock.MagicMock()
         fn.filename = '{}.metadata'.format(ts)
         fn.attrs.mtime = ts
