@@ -24,7 +24,7 @@ reMarkable table lines parser unit tests.
 import io
 import remt.parser as r_parser
 
-def test_parse_item():
+def test_parse_item() -> None:
     """
     Test parsing of a drawing item.
     """
