@@ -26,7 +26,7 @@ from cytoolz.functoolz import flip  # type: ignore
 
 from remt.util import split
 
-def test_split():
+def test_split() -> None:
     """
     Test splitting sequence by a function key.
     """
