@@ -68,6 +68,7 @@ import cytoolz.functoolz as ftz  # type: ignore
 import math
 import operator
 import typing as tp
+from collections.abc import Iterator
 from functools import partial
 from itertools import groupby
 
@@ -81,8 +82,9 @@ PI_2 = math.pi / 2
 LineConstWidthCalc = tp.Callable[[rdata.Stroke], float]
 LineVarWidthCalc = tp.Callable[[rdata.Stroke, rdata.Segment], float]
 
-def line_const(calc: LineConstWidthCalc, stroke: rdata.Stroke) \
-        -> tp.Iterable[rdata.LinePath]:
+def line_const(
+        calc: LineConstWidthCalc, stroke: rdata.Stroke
+) -> Iterator[rdata.LinePath]:
     """
     Return collection of lines of constant width and pressure between
     segments.
@@ -102,8 +104,9 @@ def line_const(calc: LineConstWidthCalc, stroke: rdata.Stroke) \
     # set pressure to 1 as line is pressure insensitive
     yield rdata.LinePath(width, 1, points)
 
-def line_var_pressure(calc: LineConstWidthCalc, stroke: rdata.Stroke) \
-        -> tp.Iterable[rdata.LinePath]:
+def line_var_pressure(
+        calc: LineConstWidthCalc, stroke: rdata.Stroke
+) -> Iterator[rdata.LinePath]:
     """
     Return collection of lines of constant width, but varying pressure
     between segments.
@@ -126,8 +129,9 @@ def line_var_pressure(calc: LineConstWidthCalc, stroke: rdata.Stroke) \
     lines = (create_line(p, pt) for p, pt in by_pressure)
     yield from lines
 
-def line_var_width_pressure(calc: LineVarWidthCalc, stroke: rdata.Stroke) \
-        -> tp.Iterable[rdata.LinePath]:
+def line_var_width_pressure(
+        calc: LineVarWidthCalc, stroke: rdata.Stroke
+) -> Iterator[rdata.LinePath]:
     """
     Return collection of lines having varying width or varying pressure
     between segments.
@@ -156,8 +160,9 @@ def line_var_width_pressure(calc: LineVarWidthCalc, stroke: rdata.Stroke) \
     lines = (rdata.LinePath(w / 1000, p, pt) for (w, p), pt in groups)
     yield from lines
 
-def group_line_segments(segments: tp.Iterable[T], key: tp.Callable[[T], V]) \
-        -> tp.Iterable[tp.Tuple[V, rdata.Points]]:
+def group_line_segments(
+        segments: Iterator[T], key: tp.Callable[[T], V]
+) -> Iterator[tp.Tuple[V, rdata.Points]]:
     """
     Group line segments using key function.
     """
